* Fix parallel build
* Respect LDFLAGS
* Fix build with gmake 3.82
* Respect AR

https://bugs.gentoo.org/337479
https://bugs.gentoo.org/725292

--- a/lib/Makefile
+++ b/lib/Makefile
@@ -44,7 +44,7 @@
 
 #  build fitssub library
 $(ARCH)/libfitsLib.a: ${OBJECTS}
-	ar rv $(ARCH)/libfitsLib.a ${OBJECTS}
+	${AR} rv $(ARCH)/libfitsLib.a ${OBJECTS}
 	${RANLIB} $(ARCH)/libfitsLib.a
 
 clean:
--- a/Makefile.in
+++ b/Makefile.in
@@ -61,26 +61,26 @@
 LIBDIR = lib/$(ARCH)/
 CFLAGS = -Iinclude -Ifitssubs @MOTIF_CPPFLAGS@ @X_CFLAGS@ \
 	$(DEBUG) $(OSFLAGS) @CFLAGS@ 
-LIBS = @MOTIF_LIBS@ -lfitsLib
-LDFLAGS = @MOTIF_LDFLAGS@ @X_LIBS@ -L$(LIBDIR)
+LIBS = @MOTIF_LIBS@ @X_LIBS@ -L$(LIBDIR) -lfitsLib
+LDFLAGS = @LDFLAGS@ @MOTIF_LDFLAGS@
 
 all:  $(TARGETS)
 
 # update source/object directory
 srcupdate: 
-	cd src; $(MAKE)
+	$(MAKE) -C src
 
 # update fitssubs source/object directory
 fitsupdate: 
-	cd fitssubs; $(MAKE)
+	$(MAKE) -C fitssubs
 
 # update fitssubs library directory
-libupdate: 
-	cd lib; $(MAKE) RANLIB="$(RANLIB)"
+libupdate: fitsupdate srcupdate
+	$(MAKE) RANLIB="$(RANLIB)" -C lib
 
 # Link Obitview
-XFITSview: lib/$(ARCH)/libfitsLib.a  src/*.c XFITSview.c
-	$(CC) XFITSview.c -o XFITSview  $(CFLAGS) src/*.o $(LDFLAGS) $(LIBS)
+XFITSview: XFITSview.c libupdate
+	$(CC) $(LDFLAGS) XFITSview.c -o XFITSview  $(CFLAGS) src/*.o $(LIBS)
 
 # make gzipped tar backup of directory
 backup:	
--- a/fitssubs/Makefile.in
+++ b/fitssubs/Makefile.in
@@ -69,7 +69,7 @@
 
 
 # create library directory if needed
-../lib/$(ARCH): ../lib
+$(LIBDIR): ../lib
 	mkdir ../lib/$(ARCH)
 
 clean:
